GroupingListItem

Enum GroupingListItem 

enum GroupingListItem {
    Singleton(u32),
    Group(GroupingListGroup),
}
An item in the GroupingListModel.

Variants



Singleton(u32)

An item that is not in a group.



Group(GroupingListGroup)

A group of items.

Implementations

Source

impl GroupingListItem

fn with_range(range: RangeInclusive<u32>, model: &ListModel) -> Self

Construct a list item with the given range for the given model.

fn contains(&self, position: u32) -> bool

Whether this list item contains the given position.

fn start(&self) -> u32

The position of the first item in this list item.

fn end(&self) -> u32

The position of the last item in this list item.

fn len(&self) -> u32

The length of the range of this list item.

fn handle_removal(&mut self, position: u32, removed: u32)

Handle the given removal of items that might affect this group.

This function panics if there would be no items left in this group.

fn handle_addition(&mut self, position: u32, added: u32)

Handle the given addition of items that might affect this group.

fn add(&self, position: u32, added: u32, model: &ListModel) -> Option<Self>

Add items to this list item.

Returns the newly created group if this item was a singleton.

Panics if the added items are not contiguous to the current ones.

fn split(&self, position: u32) -> Self

Split this group at the given position.

position must be greater than the start and lower or equal to the end of this group.

Returns the new list item containing the second part of the group, starting at at.