enum GroupingListItem {
Singleton(u32),
Group(GroupingListGroup),
}Expand description
An item in the GroupingListModel.
Variants
Implementations
Sourceimpl GroupingListItem
impl GroupingListItem
Sourcefn with_range(range: RangeInclusive<u32>, model: &ListModel) -> Self
fn with_range(range: RangeInclusive<u32>, model: &ListModel) -> Self
Construct a list item with the given range for the given model.
Sourcefn handle_removal(&mut self, position: u32, removed: u32)
fn handle_removal(&mut self, position: u32, removed: u32)
Handle the given removal of items that might affect this group.
This function panics if there would be no items left in this group.
Sourcefn handle_addition(&mut self, position: u32, added: u32)
fn handle_addition(&mut self, position: u32, added: u32)
Handle the given addition of items that might affect this group.